# turbo-flask

[![Build status](https://github.com/miguelgrinberg/turbo-flask/workflows/build/badge.svg)](https://github.com/miguelgrinberg/turbo-flask/actions) [![codecov](https://codecov.io/gh/miguelgrinberg/turbo-flask/branch/main/graph/badge.svg)](https://codecov.io/gh/miguelgrinberg/turbo-flask)

Integration of Hotwire's Turbo library with Flask, to allow you to create
applications that look and feel like single-page apps without using
JavaScript.

![Todo App Demo](todo-demo.gif)

Resources
---------

-  [Documentation](https://turbo-flask.readthedocs.io/en/latest/)
-  [PyPI](https://pypi.python.org/pypi/turbo-flask)
-  [Change Log](https://github.com/miguelgrinberg/turbo-flask/blob/main/CHANGES.md)
